bayespy.inference.vmp.nodes.multinomial.MultinomialDistribution.compute_message_to_parent
=========================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.multinomial

.. automethod:: MultinomialDistribution.compute_message_to_parent